==> rust_ephem-0.1.3.tar.gz: rust_ephem-0.1.3/tests/sun_moon_calculation_tests.rs <==
/// Unit tests for Sun and Moon position calculations

#[cfg(test)]
mod sun_moon_tests {
    use chrono::{DateTime, Utc};

    // Test helper to calculate Sun position (we need to expose internal function)
    // For now, we'll test indirectly through the Ephemeris API via Python bindings
    // Direct unit tests would require exposing calculate_sun_position_gcrs and
    // calculate_moon_position_gcrs functions

    #[test]
    fn test_sun_position_reasonable_range() {
        // This is a basic sanity check that we can expand if functions are exposed
        // For now, integration tests via Python provide coverage

        // Expected Sun distance range: approximately 147-152 million km (0.983 - 1.017 AU)
        let min_sun_distance_km = 147e6;
        let max_sun_distance_km = 152e6;

        // Verify our constants are reasonable
        assert!(min_sun_distance_km > 0.0);
        assert!(max_sun_distance_km > min_sun_distance_km);
    }

    #[test]
    fn test_moon_position_reasonable_range() {
        // Moon's distance from Earth varies between about 356,000 and 407,000 km
        let min_moon_distance_km = 356000.0;
        let max_moon_distance_km = 407000.0;

        // Verify our constants are reasonable
        assert!(min_moon_distance_km > 0.0);
        assert!(max_moon_distance_km > min_moon_distance_km);
    }

    #[test]
    fn test_datetime_conversion() {
        // Test that datetime to JD conversion is working
        // J2000.0 epoch: 2000-01-01T12:00:00 UTC = JD 2451545.0
        let j2000_str = "2000-01-01T12:00:00Z";
        let dt = DateTime::parse_from_rfc3339(j2000_str)
            .expect("Failed to parse J2000 time")
            .with_timezone(&Utc);

        // Calculate JD
        let jd_unix_epoch = 2440587.5;
        let seconds_per_day = 86400.0;
        let timestamp_secs = dt.timestamp() as f64;
        let days_since_epoch = timestamp_secs / seconds_per_day;
        let jd = jd_unix_epoch + days_since_epoch;

        // Should be very close to 2451545.0
        let expected_jd = 2451545.0;
        let tolerance = 0.1; // 0.1 days tolerance
        assert!(
            (jd - expected_jd).abs() < tolerance,
            "JD calculation error: got {}, expected {}",
            jd,
            expected_jd
        );
    }

    #[test]
    fn test_au_to_km_constant() {
        // Verify the AU to km conversion constant is correct
        // 1 AU = 149,597,870.7 km (IAU 2012 definition)
        const AU_TO_KM: f64 = 149597870.7;

        // Should be approximately 150 million km
        assert!(AU_TO_KM > 149e6 && AU_TO_KM < 150e6);
    }

    #[test]
    fn test_earth_gm_constant() {
        // Verify Earth's gravitational parameter
        // GM_Earth = 398,600.4418 km^3/s^2
        const GM_EARTH: f64 = 398600.4418;

        // Should be around 400,000 km^3/s^2
        assert!(GM_EARTH > 398000.0 && GM_EARTH < 399000.0);
    }
}

==> rust_ephem-0.1.6.tar.gz: rust_ephem-0.1.6/tests/sun_moon_calculation_tests.rs <==
/// Unit tests for Sun and Moon position calculations
#[cfg(test)]
mod sun_moon_tests {
    use chrono::{DateTime, Utc};

    // Test helper to calculate Sun position (we need to expose internal function)
    // For now, we'll test indirectly through the Ephemeris API via Python bindings
    // Direct unit tests would require exposing calculate_sun_position_gcrs and
    // calculate_moon_position_gcrs functions

    #[test]
    fn test_sun_position_reasonable_range() {
        // This is a basic sanity check that we can expand if functions are exposed
        // For now, integration tests via Python provide coverage

        // Expected Sun distance range: approximately 147-152 million km (0.983 - 1.017 AU)
        let min_sun_distance_km = 147e6;
        let max_sun_distance_km = 152e6;

        // Verify our constants are reasonable
        assert!(min_sun_distance_km > 0.0);
        assert!(max_sun_distance_km > min_sun_distance_km);
    }

    #[test]
    fn test_moon_position_reasonable_range() {
        // Moon's distance from Earth varies between about 356,000 and 407,000 km
        let min_moon_distance_km = 356000.0;
        let max_moon_distance_km = 407000.0;

        // Verify our constants are reasonable
        assert!(min_moon_distance_km > 0.0);
        assert!(max_moon_distance_km > min_moon_distance_km);
    }

    #[test]
    fn test_datetime_conversion() {
        // Test that datetime to JD conversion is working
        // J2000.0 epoch: 2000-01-01T12:00:00 UTC = JD 2451545.0
        let j2000_str = "2000-01-01T12:00:00Z";
        let dt = DateTime::parse_from_rfc3339(j2000_str)
            .expect("Failed to parse J2000 time")
            .with_timezone(&Utc);

        // Calculate JD
        let jd_unix_epoch = 2440587.5;
        let seconds_per_day = 86400.0;
        let timestamp_secs = dt.timestamp() as f64;
        let days_since_epoch = timestamp_secs / seconds_per_day;
        let jd = jd_unix_epoch + days_since_epoch;

        // Should be very close to 2451545.0
        let expected_jd = 2451545.0;
        let tolerance = 0.1; // 0.1 days tolerance
        assert!(
            (jd - expected_jd).abs() < tolerance,
            "JD calculation error: got {}, expected {}",
            jd,
            expected_jd
        );
    }

    #[test]
    fn test_au_to_km_constant() {
        // Verify the AU to km conversion constant is correct
        // 1 AU = 149,597,870.7 km (IAU 2012 definition)
        let au_to_km = 149597870.7;

        // Should be approximately 150 million km
        assert!(au_to_km > 149e6);
        assert!(au_to_km < 150e6);
    }

    #[test]
    fn test_earth_gm_constant() {
        // Verify Earth's gravitational parameter
        // GM_Earth = 398,600.4418 km^3/s^2
        let gm_earth = 398600.4418;

        // Should be around 400,000 km^3/s^2
        assert!(gm_earth > 398000.0);
        assert!(gm_earth < 399000.0);
    }
}
